@@ -1,22 +1,25 @@
-from .applied_add_on import AppliedAddOn
 from .applied_coupon import AppliedCoupon
 from .billable_metric import BillableMetric, BillableMetricGroup
 from .charge import Charge, Charges, ChargesResponse
 from .coupon import Coupon, LimitationConfiguration
 from .credit import CreditResponse, CreditsResponse
-from .credit_note import Item, Items, CreditNote, CreditNoteUpdate
+from .credit_note import Item, Items, CreditNote, CreditNoteUpdate, CreditNoteEstimate
 from .plan import Plan
 from .add_on import AddOn
 from .organization import Organization, OrganizationBillingConfiguration
 from .event import Event, BatchEvent
 from .fee import Fee
-from .customer import Customer, CustomerBillingConfiguration, Metadata, MetadataList
+from .customer import Customer, CustomerBillingConfiguration, Metadata, MetadataList,\
+    MetadataResponse, MetadataResponseList, IntegrationCustomer, IntegrationCustomerResponse,\
+    IntegrationCustomersResponseList, IntegrationCustomersList
 from .invoice import InvoicePaymentStatusChange, Invoice, InvoiceMetadata, InvoiceMetadataList,\
     OneOffInvoice, InvoiceFeesList, InvoiceFee
 from .invoice_item import InvoiceItemResponse
+from .minimum_commitment import MinimumCommitment, MinimumCommitmentResponse
 from .subscription import Subscription
 from .customer_usage import Metric, ChargeObject, ChargeUsage, CustomerUsageResponse
 from .tax import Tax, Taxes, TaxResponse, TaxesResponse
-from .wallet import Wallet
+from .wallet import Wallet, RecurringTransactionRule, RecurringTransactionRuleList, \
+    RecurringTransactionRuleResponse, RecurringTransactionRuleResponseList
 from .wallet_transaction import WalletTransaction
 from .webhook_endpoint import WebhookEndpoint
